# Table of Contents

- [data-object-modeling-v3](<./data-object-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Data Object (Meta Model v3)](<./Modeling-Data-Object-Meta-Model-v3.md>)
  - [Overview](<./Modeling-Data-Object-Meta-Model-v3/Overview.md>)
  - [Resources](<./Modeling-Data-Object-Meta-Model-v3/Resources.md>)
